# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    DeploymentStatus,
    DomainStatus,
    GitProvider,
    NetworkType,
    ServiceSpecHealthCheckType,
    ServiceStatus,
    ServiceTemplate,
)


class Service(BaseModel):
    service: "ServiceService"


class ServiceService(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    template: ServiceTemplate
    project: "ServiceServiceProject"
    watch_paths: list[str] = Field(alias="watchPaths")
    root_directory: str = Field(alias="rootDirectory")
    custom_build_command: Optional[str] = Field(alias="customBuildCommand")
    custom_start_command: Optional[str] = Field(alias="customStartCommand")
    output_dir: Optional[str] = Field(alias="outputDir")
    resource_limit: Optional["ServiceServiceResourceLimit"] = Field(
        alias="resourceLimit"
    )
    created_at: Any = Field(alias="createdAt")
    market_item_code: Optional[str] = Field(alias="marketItemCode")
    spec: Optional["ServiceServiceSpec"]
    marketplace_item: Optional["ServiceServiceMarketplaceItem"] = Field(
        alias="marketplaceItem"
    )
    status: ServiceStatus
    dns_name: str = Field(alias="dnsName")
    port_forwarded_host: str = Field(alias="portForwardedHost")
    health_check_v_2: Optional["ServiceServiceHealthCheckV2"] = Field(
        alias="healthCheckV2"
    )
    suspended_at: Optional[Any] = Field(alias="suspendedAt")
    once_product: Optional[str] = Field(alias="onceProduct")
    failure_threshold: int = Field(alias="failureThreshold")
    deployments: list["ServiceServiceDeployments"]
    domains: list["ServiceServiceDomains"]


class ServiceServiceProject(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    description: Optional[str]
    icon_url: Optional[str] = Field(alias="iconURL")
    created_at: Any = Field(alias="createdAt")
    owner: Optional["ServiceServiceProjectOwner"]
    collaborators: list["ServiceServiceProjectCollaborators"]
    invitations: list["ServiceServiceProjectInvitations"]
    region: "ServiceServiceProjectRegion"
    pull_request: Optional[str] = Field(alias="pullRequest")
    environments: list["ServiceServiceProjectEnvironments"]
    services: list["ServiceServiceProjectServices"]


class ServiceServiceProjectOwner(BaseModel):
    id: Any = Field(alias="_id")


class ServiceServiceProjectCollaborators(BaseModel):
    id: Any = Field(alias="_id")


class ServiceServiceProjectInvitations(BaseModel):
    id: Any = Field(alias="_id")


class ServiceServiceProjectRegion(BaseModel):
    id: str


class ServiceServiceProjectEnvironments(BaseModel):
    id: Any = Field(alias="_id")


class ServiceServiceProjectServices(BaseModel):
    id: Any = Field(alias="_id")


class ServiceServiceResourceLimit(BaseModel):
    cpu: Optional[int]
    memory: Optional[int]


class ServiceServiceSpec(BaseModel):
    id: Optional[str]
    name: str
    icon: Optional[str]
    ports: Optional[list["ServiceServiceSpecPorts"]]
    volumes: Optional[list["ServiceServiceSpecVolumes"]]
    init_rules: Optional[list["ServiceServiceSpecInitRules"]] = Field(alias="initRules")


class ServiceServiceSpecPorts(BaseModel):
    id: str


class ServiceServiceSpecVolumes(BaseModel):
    id: str


class ServiceServiceSpecInitRules(BaseModel):
    id: str


class ServiceServiceMarketplaceItem(BaseModel):
    code: str
    name: str
    icon_url: str = Field(alias="iconURL")
    description: str
    network_type: NetworkType = Field(alias="networkType")


class ServiceServiceHealthCheckV2(BaseModel):
    type: ServiceSpecHealthCheckType
    port: str


class ServiceServiceDeployments(BaseModel):
    id: Any = Field(alias="_id")
    git_provider: GitProvider = Field(alias="gitProvider")
    repo_owner: str = Field(alias="repoOwner")
    repo_name: str = Field(alias="repoName")
    ref: str
    commit_sha: str = Field(alias="commitSHA")
    commit_message: str = Field(alias="commitMessage")
    project_id: Any = Field(alias="projectID")
    service_id: Any = Field(alias="serviceID")
    environment_id: Any = Field(alias="environmentID")
    status: DeploymentStatus
    created_at: Any = Field(alias="createdAt")
    plan_type: Optional[str] = Field(alias="planType")
    plan_meta: Optional[Any] = Field(alias="planMeta")
    scheduled_at: Optional[Any] = Field(alias="scheduledAt")
    started_at: Optional[Any] = Field(alias="startedAt")
    finished_at: Optional[Any] = Field(alias="finishedAt")
    canceled_at: Optional[Any] = Field(alias="canceledAt")
    serverless: Optional[bool]


class ServiceServiceDomains(BaseModel):
    id: Any = Field(alias="_id")
    domain: str
    redirect_to: Optional[str] = Field(alias="redirectTo")
    service_id: Any = Field(alias="serviceID")
    project_id: Any = Field(alias="projectID")
    environment_id: Any = Field(alias="environmentID")
    status: DomainStatus
    status_reason: Optional[str] = Field(alias="statusReason")
    created_at: Any = Field(alias="createdAt")
    port_name: Optional[str] = Field(alias="portName")
    is_generated: bool = Field(alias="isGenerated")


Service.model_rebuild()
ServiceService.model_rebuild()
ServiceServiceProject.model_rebuild()
ServiceServiceSpec.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class ServicePlanTypePlanMeta(BaseModel):
    service_plan_type_plan_meta: "ServicePlanTypePlanMetaServicePlanTypePlanMeta" = (
        Field(alias="servicePlanTypePlanMeta")
    )


class ServicePlanTypePlanMetaServicePlanTypePlanMeta(BaseModel):
    type: str
    meta: Optional[Any]


ServicePlanTypePlanMeta.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UserTemplates(BaseModel):
    user_templates: "UserTemplatesUserTemplates" = Field(alias="userTemplates")


class UserTemplatesUserTemplates(BaseModel):
    page_info: "UserTemplatesUserTemplatesPageInfo" = Field(alias="pageInfo")
    edges: list[Optional["UserTemplatesUserTemplatesEdges"]]


class UserTemplatesUserTemplatesPageInfo(BaseModel):
    total_count: int = Field(alias="totalCount")
    has_next_page: bool = Field(alias="hasNextPage")
    has_previous_page: bool = Field(alias="hasPreviousPage")
    start_cursor: str = Field(alias="startCursor")
    end_cursor: str = Field(alias="endCursor")


class UserTemplatesUserTemplatesEdges(BaseModel):
    cursor: str


UserTemplates.model_rebuild()
UserTemplatesUserTemplates.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class RenameProject(BaseModel):
    rename_project: bool = Field(alias="renameProject")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class Users(BaseModel):
    users: "UsersUsers"


class UsersUsers(BaseModel):
    page_info: "UsersUsersPageInfo" = Field(alias="pageInfo")
    edges: list[Optional["UsersUsersEdges"]]


class UsersUsersPageInfo(BaseModel):
    total_count: int = Field(alias="totalCount")
    has_next_page: bool = Field(alias="hasNextPage")
    has_previous_page: bool = Field(alias="hasPreviousPage")
    start_cursor: str = Field(alias="startCursor")
    end_cursor: str = Field(alias="endCursor")


class UsersUsersEdges(BaseModel):
    node: "UsersUsersEdgesNode"
    cursor: str


class UsersUsersEdgesNode(BaseModel):
    id: Any = Field(alias="_id")


Users.model_rebuild()
UsersUsers.model_rebuild()
UsersUsersEdges.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class KickCollaborator(BaseModel):
    kick_collaborator: bool = Field(alias="kickCollaborator")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class CreateMySQLDatabase(BaseModel):
    create_my_sql_database: bool = Field(alias="createMySQLDatabase")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class SetAutoRestart(BaseModel):
    set_auto_restart: bool = Field(alias="setAutoRestart")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any

from pydantic import Field

from .base_model import BaseModel


class BuildLogs(BaseModel):
    build_logs: list["BuildLogsBuildLogs"] = Field(alias="buildLogs")


class BuildLogsBuildLogs(BaseModel):
    message: str
    timestamp: Any


BuildLogs.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class RenewServer(BaseModel):
    renew_server: bool = Field(alias="renewServer")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any

from pydantic import Field

from .base_model import BaseModel


class Environments(BaseModel):
    environments: list["EnvironmentsEnvironments"]


class EnvironmentsEnvironments(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    project_id: Any = Field(alias="projectID")
    created_at: Any = Field(alias="createdAt")


Environments.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class InviteUserToProject(BaseModel):
    invite_user_to_project: str = Field(alias="inviteUserToProject")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CreateEnvironmentVariable(BaseModel):
    create_environment_variable: (
        "CreateEnvironmentVariableCreateEnvironmentVariable"
    ) = Field(alias="createEnvironmentVariable")


class CreateEnvironmentVariableCreateEnvironmentVariable(BaseModel):
    id: Any = Field(alias="_id")
    key: str
    value: str
    environment_id: Any = Field(alias="environmentID")
    created_at: Any = Field(alias="createdAt")
    exposed: Optional[bool]
    readonly: Optional[bool]
    service_id: Optional[Any] = Field(alias="serviceID")


CreateEnvironmentVariable.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Any

from pydantic import Field

from .base_model import BaseModel


class CloneGitRepoOfService(BaseModel):
    clone_git_repo_of_service: "CloneGitRepoOfServiceCloneGitRepoOfService" = Field(
        alias="cloneGitRepoOfService"
    )


class CloneGitRepoOfServiceCloneGitRepoOfService(BaseModel):
    project_id: Any = Field(alias="projectID")
    service_id: Any = Field(alias="serviceID")
    repo_url: str = Field(alias="repoURL")


CloneGitRepoOfService.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UpdateServiceImageRepo(BaseModel):
    update_service_image_repo: bool = Field(alias="updateServiceImageRepo")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UpdateRootDirectory(BaseModel):
    update_root_directory: bool = Field(alias="updateRootDirectory")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class MountVolume(BaseModel):
    mount_volume: bool = Field(alias="mountVolume")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class VerifyPhoneVerification(BaseModel):
    verify_phone_verification: bool = Field(alias="verifyPhoneVerification")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class GitRepoBranches(BaseModel):
    git_repo_branches: list[str] = Field(alias="gitRepoBranches")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CloneProjectStatus(BaseModel):
    clone_project_status: "CloneProjectStatusCloneProjectStatus" = Field(
        alias="cloneProjectStatus"
    )


class CloneProjectStatusCloneProjectStatus(BaseModel):
    new_project_id: Optional[Any] = Field(alias="newProjectId")
    events: list["CloneProjectStatusCloneProjectStatusEvents"]
    error: Optional[str]


class CloneProjectStatusCloneProjectStatusEvents(BaseModel):
    type: str
    created_at: Any = Field(alias="createdAt")
    message: str


CloneProjectStatus.model_rebuild()
CloneProjectStatusCloneProjectStatus.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class User(BaseModel):
    user: "UserUser"


class UserUser(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    email: str
    language: str
    github_id: Optional[int] = Field(alias="githubID")
    discord_id: Optional[str] = Field(alias="discordID")
    avatar_url: str = Field(alias="avatarURL")
    created_at: Any = Field(alias="createdAt")
    email_preference: Any = Field(alias="emailPreference")
    referral_code: str = Field(alias="referralCode")
    username: str
    referred_by: Optional["UserUserReferredBy"] = Field(alias="referredBy")
    referral_reward_redeemed: bool = Field(alias="referralRewardRedeemed")
    passed_china_identity_verification: bool = Field(
        alias="passedChinaIdentityVerification"
    )
    phone: Optional[str]


class UserUserReferredBy(BaseModel):
    name: str
    avatar_url: str = Field(alias="avatarURL")


User.model_rebuild()
UserUser.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class CancelOngoingDeployment(BaseModel):
    cancel_ongoing_deployment: bool = Field(alias="cancelOngoingDeployment")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UpdateTemplateFromFile(BaseModel):
    update_template_from_file: bool = Field(alias="updateTemplateFromFile")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DomainStatus


class AddDomain(BaseModel):
    add_domain: "AddDomainAddDomain" = Field(alias="addDomain")


class AddDomainAddDomain(BaseModel):
    id: Any = Field(alias="_id")
    domain: str
    redirect_to: Optional[str] = Field(alias="redirectTo")
    service_id: Any = Field(alias="serviceID")
    project_id: Any = Field(alias="projectID")
    environment_id: Any = Field(alias="environmentID")
    status: DomainStatus
    status_reason: Optional[str] = Field(alias="statusReason")
    created_at: Any = Field(alias="createdAt")
    port_name: Optional[str] = Field(alias="portName")
    is_generated: bool = Field(alias="isGenerated")
    dns_records: Optional[list["AddDomainAddDomainDnsRecords"]] = Field(
        alias="dnsRecords"
    )


class AddDomainAddDomainDnsRecords(BaseModel):
    record_type: str = Field(alias="recordType")
    record_name: str = Field(alias="recordName")
    record_value: str = Field(alias="recordValue")


AddDomain.model_rebuild()
AddDomainAddDomain.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UpdateServicePorts(BaseModel):
    update_service_ports: bool = Field(alias="updateServicePorts")



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CheckDomainAvailable(BaseModel):
    check_domain_available: "CheckDomainAvailableCheckDomainAvailable" = Field(
        alias="checkDomainAvailable"
    )


class CheckDomainAvailableCheckDomainAvailable(BaseModel):
    is_available: bool = Field(alias="isAvailable")
    reason: Optional[str]
    available_suffixes: list[str] = Field(alias="availableSuffixes")


CheckDomainAvailable.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UpdatePortForwardingMode(BaseModel):
    update_port_forwarding_mode: bool = Field(alias="updatePortForwardingMode")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ServiceStatus, ServiceTemplate


class CreateProject(BaseModel):
    create_project: "CreateProjectCreateProject" = Field(alias="createProject")


class CreateProjectCreateProject(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    description: Optional[str]
    icon_url: Optional[str] = Field(alias="iconURL")
    created_at: Any = Field(alias="createdAt")
    owner: Optional["CreateProjectCreateProjectOwner"]
    collaborators: list["CreateProjectCreateProjectCollaborators"]
    invitations: list["CreateProjectCreateProjectInvitations"]
    region: "CreateProjectCreateProjectRegion"
    pull_request: Optional[str] = Field(alias="pullRequest")
    groups: list["CreateProjectCreateProjectGroups"]
    environments: list["CreateProjectCreateProjectEnvironments"]
    services: list["CreateProjectCreateProjectServices"]


class CreateProjectCreateProjectOwner(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    email: str
    language: str
    github_id: Optional[int] = Field(alias="githubID")
    discord_id: Optional[str] = Field(alias="discordID")
    avatar_url: str = Field(alias="avatarURL")
    created_at: Any = Field(alias="createdAt")
    email_preference: Any = Field(alias="emailPreference")
    referral_code: str = Field(alias="referralCode")
    username: str
    referral_reward_redeemed: bool = Field(alias="referralRewardRedeemed")
    passed_china_identity_verification: bool = Field(
        alias="passedChinaIdentityVerification"
    )
    phone: Optional[str]


class CreateProjectCreateProjectCollaborators(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    email: str
    language: str
    github_id: Optional[int] = Field(alias="githubID")
    discord_id: Optional[str] = Field(alias="discordID")
    avatar_url: str = Field(alias="avatarURL")
    created_at: Any = Field(alias="createdAt")
    email_preference: Any = Field(alias="emailPreference")
    referral_code: str = Field(alias="referralCode")
    username: str
    referral_reward_redeemed: bool = Field(alias="referralRewardRedeemed")
    passed_china_identity_verification: bool = Field(
        alias="passedChinaIdentityVerification"
    )
    phone: Optional[str]


class CreateProjectCreateProjectInvitations(BaseModel):
    id: Any = Field(alias="_id")
    inviter: "CreateProjectCreateProjectInvitationsInviter"
    invitee: Optional["CreateProjectCreateProjectInvitationsInvitee"]
    email: str
    project: "CreateProjectCreateProjectInvitationsProject"
    invited_at: Any = Field(alias="invitedAt")
    accepted_at: Optional[Any] = Field(alias="acceptedAt")
    cancelled_at: Optional[Any] = Field(alias="cancelledAt")
    leaved_at: Optional[Any] = Field(alias="leavedAt")


class CreateProjectCreateProjectInvitationsInviter(BaseModel):
    id: Any = Field(alias="_id")


class CreateProjectCreateProjectInvitationsInvitee(BaseModel):
    id: Any = Field(alias="_id")


class CreateProjectCreateProjectInvitationsProject(BaseModel):
    id: Any = Field(alias="_id")


class CreateProjectCreateProjectRegion(BaseModel):
    id: str
    code: str
    name: str
    description: str
    available: bool
    coordinates: list[float]
    continent: str
    country: str
    city: str


class CreateProjectCreateProjectGroups(BaseModel):
    name: Optional[str]
    service_i_ds: list[Any] = Field(alias="serviceIDs")


class CreateProjectCreateProjectEnvironments(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    project_id: Any = Field(alias="projectID")
    created_at: Any = Field(alias="createdAt")


class CreateProjectCreateProjectServices(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    template: ServiceTemplate
    project: "CreateProjectCreateProjectServicesProject"
    watch_paths: list[str] = Field(alias="watchPaths")
    root_directory: str = Field(alias="rootDirectory")
    custom_build_command: Optional[str] = Field(alias="customBuildCommand")
    custom_start_command: Optional[str] = Field(alias="customStartCommand")
    output_dir: Optional[str] = Field(alias="outputDir")
    created_at: Any = Field(alias="createdAt")
    market_item_code: Optional[str] = Field(alias="marketItemCode")
    spec: Optional["CreateProjectCreateProjectServicesSpec"]
    status: ServiceStatus
    dns_name: str = Field(alias="dnsName")
    port_forwarded_host: str = Field(alias="portForwardedHost")
    suspended_at: Optional[Any] = Field(alias="suspendedAt")
    once_product: Optional[str] = Field(alias="onceProduct")
    failure_threshold: int = Field(alias="failureThreshold")
    deployments: list["CreateProjectCreateProjectServicesDeployments"]
    domains: list["CreateProjectCreateProjectServicesDomains"]


class CreateProjectCreateProjectServicesProject(BaseModel):
    id: Any = Field(alias="_id")


class CreateProjectCreateProjectServicesSpec(BaseModel):
    id: Optional[str]


class CreateProjectCreateProjectServicesDeployments(BaseModel):
    id: Any = Field(alias="_id")


class CreateProjectCreateProjectServicesDomains(BaseModel):
    id: Any = Field(alias="_id")


CreateProject.model_rebuild()
CreateProjectCreateProject.model_rebuild()
CreateProjectCreateProjectInvitations.model_rebuild()
CreateProjectCreateProjectServices.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ServiceTemplate, TemplateVariableType


class CreateTemplate(BaseModel):
    create_template: "CreateTemplateCreateTemplate" = Field(alias="createTemplate")


class CreateTemplateCreateTemplate(BaseModel):
    code: str
    name: str
    description: str
    cover_url: Optional[str] = Field(alias="coverURL")
    icon_url: Optional[str] = Field(alias="iconURL")
    preview_url: Optional[str] = Field(alias="previewURL")
    author: "CreateTemplateCreateTemplateAuthor"
    created_at: Any = Field(alias="createdAt")
    readme: str
    resource_usage: Optional["CreateTemplateCreateTemplateResourceUsage"] = Field(
        alias="resourceUsage"
    )
    services: list["CreateTemplateCreateTemplateServices"]
    deployment_cnt: int = Field(alias="deploymentCnt")
    tags: Optional[list[str]]
    variables: Optional[list["CreateTemplateCreateTemplateVariables"]]


class CreateTemplateCreateTemplateAuthor(BaseModel):
    username: str
    avatar_url: str = Field(alias="avatarURL")


class CreateTemplateCreateTemplateResourceUsage(BaseModel):
    cpu: Optional[int]
    memory: Optional[int]


class CreateTemplateCreateTemplateServices(BaseModel):
    name: str
    template: ServiceTemplate
    git_repo_id: Optional[int] = Field(alias="gitRepoID")
    git_repo: Optional["CreateTemplateCreateTemplateServicesGitRepo"] = Field(
        alias="gitRepo"
    )
    branch_name: Optional[str] = Field(alias="branchName")
    custom_build_command: Optional[str] = Field(alias="customBuildCommand")
    custom_start_command: Optional[str] = Field(alias="customStartCommand")
    output_dir: Optional[str] = Field(alias="outputDir")
    root_directory: Optional[str] = Field(alias="rootDirectory")
    watch_paths: Optional[list[str]] = Field(alias="watchPaths")
    plan_type: Optional[str] = Field(alias="planType")
    plan_meta: Optional[Any] = Field(alias="planMeta")
    prebuilt_item: Optional["CreateTemplateCreateTemplateServicesPrebuiltItem"] = Field(
        alias="prebuiltItem"
    )
    variables: Optional[Any]
    spec: Optional["CreateTemplateCreateTemplateServicesSpec"]


class CreateTemplateCreateTemplateServicesGitRepo(BaseModel):
    id: int


class CreateTemplateCreateTemplateServicesPrebuiltItem(BaseModel):
    id: Optional[str]


class CreateTemplateCreateTemplateServicesSpec(BaseModel):
    id: Optional[str]


class CreateTemplateCreateTemplateVariables(BaseModel):
    type: TemplateVariableType
    question: str
    key: str
    desc: str


CreateTemplate.model_rebuild()
CreateTemplateCreateTemplate.model_rebuild()
CreateTemplateCreateTemplateServices.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class BuildPlan(BaseModel):
    build_plan: list["BuildPlanBuildPlan"] = Field(alias="buildPlan")


class BuildPlanBuildPlan(BaseModel):
    key: str
    value: str
    name: Optional[str]
    description: Optional[str]
    icon: Optional[str]


BuildPlan.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ServiceSpecGitSource, ServiceSpecHealthCheckType, ServiceSpecPortType


class PrebuiltMarketplaceItems(BaseModel):
    prebuilt_marketplace_items: list[
        "PrebuiltMarketplaceItemsPrebuiltMarketplaceItems"
    ] = Field(alias="prebuiltMarketplaceItems")


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItems(BaseModel):
    id: Optional[str]
    name: str
    icon: Optional[str]
    source: "PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsSource"
    ports: Optional[list["PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsPorts"]]
    volumes: Optional[list["PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsVolumes"]]
    instructions: Optional[
        list["PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsInstructions"]
    ]
    env: Optional[list["PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsEnv"]]
    init_rules: Optional[
        list["PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsInitRules"]
    ] = Field(alias="initRules")
    configs: Optional[list["PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsConfigs"]]
    gpu: Optional["PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsGpu"]
    health_check: Optional[
        "PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsHealthCheck"
    ] = Field(alias="healthCheck")
    port_forwarding: Optional[
        "PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsPortForwarding"
    ] = Field(alias="portForwarding")


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsSource(BaseModel):
    image: Optional[str]
    username: Optional[str]
    password: Optional[str]
    source: Optional[ServiceSpecGitSource]
    repo_id: Optional[int] = Field(alias="repoID")
    upload_id: Optional[str] = Field(alias="uploadID")
    branch: Optional[str]
    submodule_name: Optional[str] = Field(alias="submoduleName")
    watch_paths: Optional[list[str]] = Field(alias="watchPaths")
    root_directory: Optional[str] = Field(alias="rootDirectory")
    dockerfile: Optional[str]
    command: Optional[list[str]]
    args: Optional[list[str]]
    run_as_user_id: Optional[int] = Field(alias="runAsUserID")


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsPorts(BaseModel):
    id: str
    port: int
    type: ServiceSpecPortType


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsVolumes(BaseModel):
    id: str
    dir: str


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsInstructions(BaseModel):
    title: str
    content: str


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsEnv(BaseModel):
    key: str
    default: Optional[str]
    expose: Optional[bool]


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsInitRules(BaseModel):
    id: str
    image: Optional[str]
    command: Optional[list[str]]
    volumes: Optional[
        list["PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsInitRulesVolumes"]
    ]


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsInitRulesVolumes(BaseModel):
    id: str


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsConfigs(BaseModel):
    path: str
    template: str
    permission: Optional[int]
    envsubst: Optional[bool]


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsGpu(BaseModel):
    enabled: bool


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsHealthCheck(BaseModel):
    type: ServiceSpecHealthCheckType
    port: str


class PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsPortForwarding(BaseModel):
    enabled: bool


PrebuiltMarketplaceItems.model_rebuild()
PrebuiltMarketplaceItemsPrebuiltMarketplaceItems.model_rebuild()
PrebuiltMarketplaceItemsPrebuiltMarketplaceItemsInitRules.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class Objects(BaseModel):
    objects: Optional["ObjectsObjects"]


class ObjectsObjects(BaseModel):
    objects: list["ObjectsObjectsObjects"]
    is_truncated: bool = Field(alias="isTruncated")
    next_continuation_token: Optional[str] = Field(alias="nextContinuationToken")


class ObjectsObjectsObjects(BaseModel):
    key: str
    size: int
    etag: str
    last_modified: Any = Field(alias="lastModified")
    storage_class: str = Field(alias="storageClass")
    content_type: Optional[str] = Field(alias="contentType")


Objects.model_rebuild()
ObjectsObjects.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UpdateUserProfile(BaseModel):
    update_user_profile: bool = Field(alias="updateUserProfile")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class RequestPhoneVerification(BaseModel):
    request_phone_verification: "RequestPhoneVerificationRequestPhoneVerification" = (
        Field(alias="requestPhoneVerification")
    )


class RequestPhoneVerificationRequestPhoneVerification(BaseModel):
    verification_id: str = Field(alias="verificationID")


RequestPhoneVerification.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class RevealManagedServerInitialPassword(BaseModel):
    reveal_managed_server_initial_password: str = Field(
        alias="revealManagedServerInitialPassword"
    )



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class CancelInvitation(BaseModel):
    cancel_invitation: bool = Field(alias="cancelInvitation")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class Buckets(BaseModel):
    buckets: Optional[list[Optional["BucketsBuckets"]]]


class BucketsBuckets(BaseModel):
    name: str
    creation_date: Any = Field(alias="creationDate")


Buckets.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Any

from pydantic import Field

from .base_model import BaseModel


class CloneProject(BaseModel):
    clone_project: "CloneProjectCloneProject" = Field(alias="cloneProject")


class CloneProjectCloneProject(BaseModel):
    new_project_id: Any = Field(alias="newProjectId")


CloneProject.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class PostgresDatabases(BaseModel):
    postgres_databases: Optional[
        list[Optional["PostgresDatabasesPostgresDatabases"]]
    ] = Field(alias="postgresDatabases")


class PostgresDatabasesPostgresDatabases(BaseModel):
    name: str


PostgresDatabases.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class CleanupLogs(BaseModel):
    cleanup_logs: "CleanupLogsCleanupLogs" = Field(alias="cleanupLogs")


class CleanupLogsCleanupLogs(BaseModel):
    status: str
    count: int


CleanupLogs.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class ExecuteDatabaseCommand(BaseModel):
    execute_database_command: str = Field(alias="executeDatabaseCommand")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class SetVariableProperty(BaseModel):
    set_variable_property: bool = Field(alias="setVariableProperty")



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class MysqlDatabases(BaseModel):
    mysql_databases: Optional[list[Optional["MysqlDatabasesMysqlDatabases"]]] = Field(
        alias="mysqlDatabases"
    )


class MysqlDatabasesMysqlDatabases(BaseModel):
    name: str


MysqlDatabases.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class Referrer(BaseModel):
    referrer: "ReferrerReferrer"


class ReferrerReferrer(BaseModel):
    name: str
    avatar_url: str = Field(alias="avatarURL")


Referrer.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class PutObject(BaseModel):
    put_object: "PutObjectPutObject" = Field(alias="putObject")


class PutObjectPutObject(BaseModel):
    key: str
    size: int
    etag: str
    last_modified: Any = Field(alias="lastModified")
    storage_class: str = Field(alias="storageClass")
    content_type: Optional[str] = Field(alias="contentType")


PutObject.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ServiceStatus, ServiceTemplate


class Project(BaseModel):
    project: "ProjectProject"


class ProjectProject(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    description: Optional[str]
    icon_url: Optional[str] = Field(alias="iconURL")
    created_at: Any = Field(alias="createdAt")
    owner: Optional["ProjectProjectOwner"]
    collaborators: list["ProjectProjectCollaborators"]
    invitations: list["ProjectProjectInvitations"]
    region: "ProjectProjectRegion"
    pull_request: Optional[str] = Field(alias="pullRequest")
    groups: list["ProjectProjectGroups"]
    environments: list["ProjectProjectEnvironments"]
    services: list["ProjectProjectServices"]


class ProjectProjectOwner(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    email: str
    language: str
    github_id: Optional[int] = Field(alias="githubID")
    discord_id: Optional[str] = Field(alias="discordID")
    avatar_url: str = Field(alias="avatarURL")
    created_at: Any = Field(alias="createdAt")
    email_preference: Any = Field(alias="emailPreference")
    referral_code: str = Field(alias="referralCode")
    username: str
    referral_reward_redeemed: bool = Field(alias="referralRewardRedeemed")
    passed_china_identity_verification: bool = Field(
        alias="passedChinaIdentityVerification"
    )
    phone: Optional[str]


class ProjectProjectCollaborators(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    email: str
    language: str
    github_id: Optional[int] = Field(alias="githubID")
    discord_id: Optional[str] = Field(alias="discordID")
    avatar_url: str = Field(alias="avatarURL")
    created_at: Any = Field(alias="createdAt")
    email_preference: Any = Field(alias="emailPreference")
    referral_code: str = Field(alias="referralCode")
    username: str
    referral_reward_redeemed: bool = Field(alias="referralRewardRedeemed")
    passed_china_identity_verification: bool = Field(
        alias="passedChinaIdentityVerification"
    )
    phone: Optional[str]


class ProjectProjectInvitations(BaseModel):
    id: Any = Field(alias="_id")
    inviter: "ProjectProjectInvitationsInviter"
    invitee: Optional["ProjectProjectInvitationsInvitee"]
    email: str
    project: "ProjectProjectInvitationsProject"
    invited_at: Any = Field(alias="invitedAt")
    accepted_at: Optional[Any] = Field(alias="acceptedAt")
    cancelled_at: Optional[Any] = Field(alias="cancelledAt")
    leaved_at: Optional[Any] = Field(alias="leavedAt")


class ProjectProjectInvitationsInviter(BaseModel):
    id: Any = Field(alias="_id")


class ProjectProjectInvitationsInvitee(BaseModel):
    id: Any = Field(alias="_id")


class ProjectProjectInvitationsProject(BaseModel):
    id: Any = Field(alias="_id")


class ProjectProjectRegion(BaseModel):
    id: str
    code: str
    name: str
    description: str
    available: bool
    coordinates: list[float]
    continent: str
    country: str
    city: str


class ProjectProjectGroups(BaseModel):
    name: Optional[str]
    service_i_ds: list[Any] = Field(alias="serviceIDs")


class ProjectProjectEnvironments(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    project_id: Any = Field(alias="projectID")
    created_at: Any = Field(alias="createdAt")


class ProjectProjectServices(BaseModel):
    id: Any = Field(alias="_id")
    name: str
    template: ServiceTemplate
    project: "ProjectProjectServicesProject"
    watch_paths: list[str] = Field(alias="watchPaths")
    root_directory: str = Field(alias="rootDirectory")
    custom_build_command: Optional[str] = Field(alias="customBuildCommand")
    custom_start_command: Optional[str] = Field(alias="customStartCommand")
    output_dir: Optional[str] = Field(alias="outputDir")
    created_at: Any = Field(alias="createdAt")
    market_item_code: Optional[str] = Field(alias="marketItemCode")
    spec: Optional["ProjectProjectServicesSpec"]
    status: ServiceStatus
    dns_name: str = Field(alias="dnsName")
    port_forwarded_host: str = Field(alias="portForwardedHost")
    suspended_at: Optional[Any] = Field(alias="suspendedAt")
    once_product: Optional[str] = Field(alias="onceProduct")
    failure_threshold: int = Field(alias="failureThreshold")
    deployments: list["ProjectProjectServicesDeployments"]
    domains: list["ProjectProjectServicesDomains"]


class ProjectProjectServicesProject(BaseModel):
    id: Any = Field(alias="_id")


class ProjectProjectServicesSpec(BaseModel):
    id: Optional[str]


class ProjectProjectServicesDeployments(BaseModel):
    id: Any = Field(alias="_id")


class ProjectProjectServicesDomains(BaseModel):
    id: Any = Field(alias="_id")


Project.model_rebuild()
ProjectProject.model_rebuild()
ProjectProjectInvitations.model_rebuild()
ProjectProjectServices.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class DedicatedServerProviders(BaseModel):
    dedicated_server_providers: list[
        "DedicatedServerProvidersDedicatedServerProviders"
    ] = Field(alias="dedicatedServerProviders")


class DedicatedServerProvidersDedicatedServerProviders(BaseModel):
    code: str
    name: str
    icon: str
    homepage: str
    console: str
    can_refund: bool = Field(alias="canRefund")


DedicatedServerProviders.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class ReloadK3sConfig(BaseModel):
    reload_k_3_s_config: bool = Field(alias="reloadK3sConfig")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class ExecuteCommand(BaseModel):
    execute_command: "ExecuteCommandExecuteCommand" = Field(alias="executeCommand")


class ExecuteCommandExecuteCommand(BaseModel):
    exit_code: int = Field(alias="exitCode")
    output: str


ExecuteCommand.model_rebuild()



from setuptools import setup, find_packages
from pathlib import Path


README = (Path(__file__).parent / "README.md").read_text(encoding="utf-8")

setup(
    name="zeabur",
    version="0.1.1",
    description="A Python SDK for the Zeabur platform, generated from the GraphQL schema.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/brucx/zeabur-python-sdk",
    project_urls={
        "Source": "https://github.com/brucx/zeabur-python-sdk",
        "Issues": "https://github.com/brucx/zeabur-python-sdk/issues",
    },
    python_requires=">=3.8",
    packages=find_packages("src"),
    package_dir={"": "src"},
    install_requires=[
        "httpx>=0.23.0",
        "pydantic>=2.0.0",
    ],
    extras_require={
        "test": ["pytest", "pytest-asyncio"],
    },
    keywords=["zeabur", "graphql", "sdk"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Operating System :: OS Independent",
    ],
)



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class RollbackDeployment(BaseModel):
    rollback_deployment: bool = Field(alias="rollbackDeployment")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UnmountVolume(BaseModel):
    unmount_volume: bool = Field(alias="unmountVolume")



# Generated by ariadne-codegen
# Source: operations/

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class ProjectUsage(BaseModel):
    project_usage: "ProjectUsageProjectUsage" = Field(alias="projectUsage")


class ProjectUsageProjectUsage(BaseModel):
    usages: list[Optional["ProjectUsageProjectUsageUsages"]]
    budget: int
    period_start: Any = Field(alias="periodStart")
    period_end: Any = Field(alias="periodEnd")


class ProjectUsageProjectUsageUsages(BaseModel):
    usage: float
    entity: str


ProjectUsage.model_rebuild()
ProjectUsageProjectUsage.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class Regions(BaseModel):
    regions: list["RegionsRegions"]


class RegionsRegions(BaseModel):
    id: str
    code: str
    name: str
    description: str
    provider_info: Optional["RegionsRegionsProviderInfo"] = Field(alias="providerInfo")
    available: bool
    coordinates: list[float]
    continent: str
    country: str
    city: str


class RegionsRegionsProviderInfo(BaseModel):
    code: str
    name: str
    icon: str
    homepage: str
    console: str
    can_refund: bool = Field(alias="canRefund")


Regions.model_rebuild()
RegionsRegions.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class RenameEnvironment(BaseModel):
    rename_environment: bool = Field(alias="renameEnvironment")



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UpdateServiceFailureThreshold(BaseModel):
    update_service_failure_threshold: bool = Field(
        alias="updateServiceFailureThreshold"
    )



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class IsTemplateAuthor(BaseModel):
    is_template_author: bool = Field(alias="isTemplateAuthor")



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class DedicatedServerRegions(BaseModel):
    dedicated_server_regions: list["DedicatedServerRegionsDedicatedServerRegions"] = (
        Field(alias="dedicatedServerRegions")
    )


class DedicatedServerRegionsDedicatedServerRegions(BaseModel):
    id: str
    code: str
    name: str
    description: str
    provider_info: Optional[
        "DedicatedServerRegionsDedicatedServerRegionsProviderInfo"
    ] = Field(alias="providerInfo")
    available: bool
    coordinates: list[float]
    continent: str
    country: str
    city: str


class DedicatedServerRegionsDedicatedServerRegionsProviderInfo(BaseModel):
    code: str
    name: str
    icon: str
    homepage: str
    console: str
    can_refund: bool = Field(alias="canRefund")


DedicatedServerRegions.model_rebuild()
DedicatedServerRegionsDedicatedServerRegions.model_rebuild()



# Generated by ariadne-codegen
# Source: operations/

from pydantic import Field

from .base_model import BaseModel


class UpdateServerCredentials(BaseModel):
    update_server_credentials: bool = Field(alias="updateServerCredentials")



# Generated by ariadne-codegen
# Source: operations/

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class DedicatedServerPlans(BaseModel):
    dedicated_server_plans: list["DedicatedServerPlansDedicatedServerPlans"] = Field(
        alias="dedicatedServerPlans"
    )


class DedicatedServerPlansDedicatedServerPlans(BaseModel):
    name: str
    cpu: int
    memory: int
    disk: int
    egress: int
    price: int
    original_price: Optional[int] = Field(alias="originalPrice")
    gpu: Optional[str]
    features: list[str]
    available: bool
    max_outbound_bandwidth: Optional[int] = Field(alias="maxOutboundBandwidth")


DedicatedServerPlans.model_rebuild()



# Generated by ariadne-codegen
# Source: zeabur_schema.graphql

from enum import Enum


class BackupStatus(str, Enum):
    PENDING = "PENDING"
    RUNNING = "RUNNING"
    SUCCESS = "SUCCESS"
    FAILED = "FAILED"


class BuildJobStatus(str, Enum):
    PENDING = "PENDING"
    RUNNING = "RUNNING"
    SUCCESS = "SUCCESS"
    FAILED = "FAILED"


class CheckDockerImageResult(str, Enum):
    REGISTRY_NOT_SUPPORTED = "REGISTRY_NOT_SUPPORTED"
    REGISTRY_CONNECTION_FAILED = "REGISTRY_CONNECTION_FAILED"
    IMAGE_NOT_FOUND = "IMAGE_NOT_FOUND"
    TAG_NOT_FOUND = "TAG_NOT_FOUND"
    UNAUTHORIZED = "UNAUTHORIZED"
    OK = "OK"


class CopyVolumeToNewServiceStatus(str, Enum):
    UNKNOWN = "UNKNOWN"
    PREPARING = "PREPARING"
    BACKING_UP = "BACKING_UP"
    RESTORING = "RESTORING"
    COMPLETED = "COMPLETED"
    FAILED = "FAILED"


class Currency(str, Enum):
    USD = "USD"
    CNY = "CNY"


class DeploymentStatus(str, Enum):
    PENDING = "PENDING"
    FAILED = "FAILED"
    BUILDING = "BUILDING"
    DEPLOYING = "DEPLOYING"
    RUNNING = "RUNNING"
    REMOVED = "REMOVED"
    CRASHED = "CRASHED"
    CANCELED = "CANCELED"
    UNKNOWN = "UNKNOWN"


class DomainStatus(str, Enum):
    INVALID_DNS = "INVALID_DNS"
    PROVISIONING = "PROVISIONING"
    PROVISIONED = "PROVISIONED"
    ICP_NOT_FILED = "ICP_NOT_FILED"


class GitProvider(str, Enum):
    GITHUB = "GITHUB"
    GITLAB = "GITLAB"
    BITBUCKET = "BITBUCKET"


class GroupByEntity(str, Enum):
    PROJECT = "PROJECT"
    SERVICE = "SERVICE"
    ENVIRONMENT = "ENVIRONMENT"


class GroupByTime(str, Enum):
    DAY = "DAY"
    WEEK = "WEEK"
    MONTH = "MONTH"


class GroupByType(str, Enum):
    CPU = "CPU"
    MEMORY = "MEMORY"
    DISK = "DISK"
    NETWORK = "NETWORK"
    ALL = "ALL"


class MetricType(str, Enum):
    CPU = "CPU"
    MEMORY = "MEMORY"
    NETWORK = "NETWORK"
    DISK = "DISK"
    LATENCY = "LATENCY"


class NetworkType(str, Enum):
    TCP = "TCP"
    HTTP = "HTTP"


class OrderBy(str, Enum):
    ASC = "ASC"
    DESC = "DESC"


class PaymentMethodType(str, Enum):
    CARD = "CARD"
    ALIPAY = "ALIPAY"
    WECHAT = "WECHAT"
    LINEPAY = "LINEPAY"


class PortForwardingMode(str, Enum):
    UNKNOWN = "UNKNOWN"
    DISABLED = "DISABLED"
    ENABLED = "ENABLED"


class ProjectActivityType(str, Enum):
    BUILD_SCHEDULED = "BUILD_SCHEDULED"
    BUILD_STARTED = "BUILD_STARTED"
    BUILD_SUCCESS = "BUILD_SUCCESS"
    BUILD_FAILED = "BUILD_FAILED"
    DEPLOYMENT_READY = "DEPLOYMENT_READY"
    DEPLOYMENT_CRASHED = "DEPLOYMENT_CRASHED"
    DEPLOYMENT_REMOVED = "DEPLOYMENT_REMOVED"
    SERVICE_STARTING = "SERVICE_STARTING"
    SERVICE_READY = "SERVICE_READY"
    SERVICE_STOPPING = "SERVICE_STOPPING"
    SERVICE_SUSPENDED = "SERVICE_SUSPENDED"
    DOMAIN_ADDED = "DOMAIN_ADDED"
    DOMAIN_PROVISIONED = "DOMAIN_PROVISIONED"
    ENVIRONMENT_CREATED = "ENVIRONMENT_CREATED"
    ENVIRONMENT_REMOVED = "ENVIRONMENT_REMOVED"


class RegionProvider(str, Enum):
    AWS = "AWS"
    GCP = "GCP"
    DIGITALOCEAN = "DIGITALOCEAN"
    HUAWEI = "HUAWEI"
    VULTR = "VULTR"


class ServiceSpecConnectionInstructionType(str, Enum):
    PASSWORD = "PASSWORD"


class ServiceSpecGitSource(str, Enum):
    GITHUB = "GITHUB"
    LOCAL = "LOCAL"
    UPLOAD_ID = "UPLOAD_ID"


class ServiceSpecHealthCheckType(str, Enum):
    Unknown = "Unknown"
    HTTP = "HTTP"
    TCP = "TCP"


class ServiceSpecPortType(str, Enum):
    HTTP = "HTTP"
    TCP = "TCP"
    UDP = "UDP"


class ServiceStatus(str, Enum):
    STARTING = "STARTING"
    RUNNING = "RUNNING"
    STOPPING = "STOPPING"
    SUSPENDED = "SUSPENDED"
    UNKNOWN = "UNKNOWN"
    CRASHED = "CRASHED"
    PULL_FAILED = "PULL_FAILED"
    PENDING = "PENDING"
    BUILDING = "BUILDING"


class ServiceTemplate(str, Enum):
    GIT = "GIT"
    MARKETPLACE = "MARKETPLACE"
    PREBUILT = "PREBUILT"
    PREBUILT_V2 = "PREBUILT_V2"
    ONCE = "ONCE"


class SubscriptionPlan(str, Enum):
    DEVELOPER = "DEVELOPER"
    TEAM = "TEAM"
    FREE = "FREE"


class TemplateVariableType(str, Enum):
    DOMAIN = "DOMAIN"
    STRING = "STRING"


class UsageGroupByEntity(str, Enum):
    CATEGORY = "CATEGORY"
    SERVICE = "SERVICE"


class VMStatus(str, Enum):
    PENDING = "PENDING"
    STARTING = "STARTING"
    RUNNING = "RUNNING"
    STOPPING = "STOPPING"
    STOPPED = "STOPPED"
    SUSPENDED = "SUSPENDED"
    TERMINATED = "TERMINATED"
    FAILED = "FAILED"
    UNKNOWN = "UNKNOWN"
    NOT_FOUND = "NOT_FOUND"
